@@ -14,7 +14,6 @@
 #include <wx/xrc/xh_gauge.h>
 #include <wx/xrc/xh_listb.h>
 #include <wx/xrc/xh_listc.h>
-#include <wx/xrc/xh_notbk.h>
 #include <wx/xrc/xh_panel.h>
 #include <wx/xrc/xh_radbt.h>
 #include <wx/xrc/xh_scwin.h>
@@ -25,12 +24,14 @@
 #include <wx/xrc/xh_stlin.h>
 #include <wx/xrc/xh_sttxt.h>
 #include "xh_text_ex.h"
-#include <wx/xrc/xh_tree.h>
 #include <wx/xrc/xh_hyperlink.h>
 
+#include <unordered_set>
+
 void InitHandlers(wxXmlResource& res)
 {
 	res.AddHandler(new wxSizerXmlHandler);
+	res.AddHandler(new wxStaticTextXmlHandler);
 	res.AddHandler(new wxButtonXmlHandler);
 	res.AddHandler(new wxRadioButtonXmlHandler);
 	res.AddHandler(new wxTextCtrlXmlHandlerEx);
@@ -42,44 +43,51 @@ void InitHandlers(wxXmlResource& res)
 	res.AddHandler(new wxChoiceXmlHandler);
 	res.AddHandler(new wxStaticLineXmlHandler);
 	res.AddHandler(new wxBitmapButtonXmlHandler);
-	res.AddHandler(new wxStaticTextXmlHandler);
 	res.AddHandler(new wxStaticBitmapXmlHandler);
-	res.AddHandler(new wxTreeCtrlXmlHandler);
 	res.AddHandler(new wxListCtrlXmlHandler);
 	res.AddHandler(new wxCheckListBoxXmlHandler);
-	res.AddHandler(new wxGaugeXmlHandler);
 	res.AddHandler(new wxSpinCtrlXmlHandler);
-	res.AddHandler(new wxNotebookXmlHandler);
 	res.AddHandler(new wxListBoxXmlHandler);
 	res.AddHandler(new wxScrolledWindowXmlHandler);
 	res.AddHandler(new wxHyperlinkCtrlXmlHandler);
 	res.AddHandler(new wxAnimationCtrlXmlHandler);
 }
 
-void InitXrc()
+namespace {
+void LoadXrcFile(std::wstring const& file)
+{
+	static std::unordered_set<std::wstring> seen;
+
+	if (seen.insert(file).second) {
+		std::wstring dir = wxGetApp().GetResourceDir().GetPath() + L"xrc/";
+		wxXmlResource* pResource = wxXmlResource::Get();
+		pResource->LoadFile(wxString(dir + file));
+	}
+}
+}
+
+void InitXrc(std::wstring const& file)
 {
 	static bool initialized = false;
-	if (initialized) {
-		return;
-	}
-	initialized = true;
+	if (!initialized) {
+		initialized = true;
 
-	wxXmlResource *pResource = wxXmlResource::Get();
+		wxXmlResource* pResource = wxXmlResource::Get();
 
 #ifndef __WXDEBUG__
-	pResource->SetFlags(pResource->GetFlags() | wxXRC_NO_RELOADING);
+		pResource->SetFlags(pResource->GetFlags() | wxXRC_NO_RELOADING);
 #endif
 
-	InitHandlers(*pResource);
+		InitHandlers(*pResource);
+	}
 
 	fz::local_filesys fs;
 	std::wstring dir = wxGetApp().GetResourceDir().GetPath() + L"xrc/";
-	pResource->LoadFile(wxString(dir + L"certificate.xrc"));
-	pResource->LoadFile(wxString(dir + L"dialogs.xrc"));
-	pResource->LoadFile(wxString(dir + L"inputdialog.xrc"));
-	pResource->LoadFile(wxString(dir + L"netconfwizard.xrc"));
-	pResource->LoadFile(wxString(dir + L"settings.xrc"));
-	pResource->LoadFile(wxString(dir + L"sitemanager.xrc"));
-	pResource->LoadFile(wxString(dir + L"update.xrc"));
-	pResource->LoadFile(wxString(dir + L"storj.xrc"));
+	if (file.empty()) {
+		LoadXrcFile(L"dialogs.xrc");
+		LoadXrcFile(L"storj.xrc");
+	}
+	else {
+		LoadXrcFile(file);
+	}
 }
